--[[
    recording_alert.lua
    Plays .wav chimes when recording starts or stops.
    Requires OBS with LuaJIT FFI and winmm.dll (standard on Windows).
]]

local obs = obslua

-- We need LuaJIT's FFI library
local ffi = require("ffi")

-- 1) Define the function signature for PlaySoundA
ffi.cdef[[
    int PlaySoundA(const char* pszSound, void* hmod, unsigned int fdwSound);
]]

-- 2) Explicitly load the winmm library (contains PlaySoundA)
local winmm = ffi.load("winmm")

----------------------------------------------------------------------------
-- Flags for PlaySoundA:
----------------------------------------------------------------------------
-- SND_FILENAME  = 0x00020000  (interpret pszSound as a filename)
-- SND_ASYNC     = 0x0001      (play asynchronously; don't wait)
-- SND_NODEFAULT = 0x0002      (don't use the default sound if file not found)
-- SND_NOWAIT    = 0x00002000  (don't wait if the driver is busy)

local SND_FILENAME  = 0x00020000
local SND_ASYNC     = 0x0001
local SND_NODEFAULT = 0x0002
local SND_NOWAIT    = 0x00002000

----------------------------------------------------------------------------
-- If you'd like to use your own audio files, just add their paths here. They must be .wav files
----------------------------------------------------------------------------
local start_chime = "C:\\Program Files\\obs-studio\\obs-plugins\\Beep\\start.wav"
local stop_chime  = "C:\\Program Files\\obs-studio\\obs-plugins\\Beep\\stop.wav"

----------------------------------------------------------------------------
-- Helper function to play a .wav file with no popup
----------------------------------------------------------------------------
local function play_sound(filepath)
    -- Combine the flags we need
    local flags = bit.bor(SND_FILENAME, SND_ASYNC, SND_NODEFAULT, SND_NOWAIT)

    -- Call PlaySoundA from winmm
    winmm.PlaySoundA(filepath, nil, flags)
end

----------------------------------------------------------------------------
-- OBS event callback
----------------------------------------------------------------------------
function on_event(event)
    if event == obs.OBS_FRONTEND_EVENT_RECORDING_STARTED then
        play_sound(start_chime)
    elseif event == obs.OBS_FRONTEND_EVENT_RECORDING_STOPPED then
        play_sound(stop_chime)
    end
end

----------------------------------------------------------------------------
-- Called by OBS when the script is loaded
----------------------------------------------------------------------------
function script_load(settings)
    obs.obs_frontend_add_event_callback(on_event)
end

function script_description()
    return "Plays .wav chimes on start/stop recording without external pop-ups."
end
